@use "tailwindcss";
@use "utility/safelist";
@use "utility/table";
@use "utility/ckeditor-theme";
@use "utility/ckeditor";
@use "theme/fonts";
@use "theme/animations";
@use "theme/colors";
@use "theme/icons";


@use "theme/heading";
@use "tippy.js/dist/tippy.css";
@source "../../../../../vendor/cpcreation/**/*";
