<div class="flex flex-col">
  <div class="overflow-x-auto shadow">
    <div class="inline-block min-w-full align-middle">
      <div class="overflow-hidden">
        {% block crud_content %}
        {% endblock %}
      </div>
    </div>
  </div>
</div>
