:root,
.editor-theme {
    --editor-color-text: #000;
    --editor-color-bg: #fff;
    --editor-color-accent: #f0ac4d;
    --editor-color-accent-secondary: #5db85b;
    --editor-color-btn-text: #fff;
    --editor-color-btn-bg: var(--editor-color-accent);
    --editor-color-btn-bg-hover: rgba(240, 172, 77, 0.9);
    --editor-color-section-border: var(--editor-color-accent);
    --editor-color-section-label-bg: #fff;
    --editor-color-panel-label-bg: #1f2937;
    --editor-color-panel-label-text: #e5e7eb;

    --editor-font-size-title: 1.5rem;
    --editor-font-size-title-lg: 1.875rem;
    --editor-font-size-subtitle: 1.125rem;
    --editor-font-size-subtitle-lg: 1.5rem;
    --editor-font-size-lead: 1.25rem;
    --editor-font-size-lead-lg: 1.5rem;
    --editor-font-size-body: 1rem;
    --editor-font-size-body-lg: 1.25rem;
    --editor-font-size-sm: 0.875rem;
    --editor-font-size-base: 1rem;
    --editor-font-size-lg: 1.125rem;
    --editor-font-size-xl: 1.25rem;
    --editor-font-size-2xl: 1.5rem;
    --editor-font-size-btn: 0.75rem;
    --editor-font-size-section-label: 0.625rem;

    --editor-font-weight-title: 700;
    --editor-font-weight-subtitle: 700;
    --editor-font-weight-accent: 700;
    --editor-font-weight-underline: 700;
    --editor-font-weight-emphasis: 600;
    --editor-font-weight-bold: 700;
    --editor-font-weight-semibold: 600;
    --editor-font-weight-medium: 500;
    --editor-font-weight-section-label: 600;

    --editor-line-height-lead: 1.625;
    --editor-line-height-body: 1.625;
    --editor-line-height-list: 1.625;

    --editor-letter-spacing-title: -0.025em;
    --editor-letter-spacing-section-label: 0.05em;
}
