import Alpine from "alpinejs";
import morph from '@alpinejs/morph'
import focus from '@alpinejs/focus'
import Tooltip from "@ryangjchandler/alpine-tooltip";
import "alpine-turbo-drive-adapter";
import { registerDropdownPortal } from './alpine/dropdown-portal';
registerDropdownPortal(Alpine);
window.selectValue = selectValue;
window.formReset = formReset;
Alpine.plugin(morph);
Alpine.plugin(focus);
Alpine.plugin(Tooltip);
window.Alpine = Alpine;
Alpine.start();
import '@cpcreation/serenity-core-bundle/js/livePatch-alpine';
import stimulusManager from "@cpcreation/serenity-core-bundle/js/stimulusManager.js";
import {Alert} from "tailwindcss-stimulus-components";
stimulusManager.register("alert", Alert);
import { selectValue, formReset} from '@cpcreation/serenity-core-bundle/js/alpineUxLive';
import "@cpcreation/serenity-core-bundle/js/multiselect";
import "./css/style.scss";
