{% block super_admin_config_row %}
{% import '@extends/SerenityAdmin/macros/collapseForm.html.twig' as formBlocks %}
<div class="grid grid-cols-1 gap-6 lg:grid-cols-2">
  <div class="space-y-6">
    {{ formBlocks.collapseFormGroup([form.title], 'Titre', false) }}
    {{ formBlocks.collapseFormGroup([form.cardSidebar], 'Carte Sidebar', true) }}
  </div>
  <div class="space-y-6">
    {{ formBlocks.collapseFormGroup([form.logo], 'Logo', false) }}
  </div>
  <div class="space-y-6">
    {{ formBlocks.collapseFormGroup([form.notificationPanel,form.searchInput], 'Navbar', true) }}
  </div>
</div>
{% endblock %}
