@theme {
  --color-primary: oklch(0.792 0.134 148.2);
  --color-primary-hover: oklch(0.698 0.107 195.2);
  --color-secondary: oklch(0.832 0.119 146.038);
  --color-light: oklch(0.936 0.112 143.9);
  --color-accent: oklch(0.438 0.178 359.978);
  --color-accent-hover: oklch(0.333 0.135 359.43);
  --color-dark: oklch(0.484 0.055 244.8);

  --color-success: oklch(89% 0.18 150);
  --color-error: oklch(75% 0.26 20);
  --color-warning: oklch(85% 0.19 70);
  --color-info: oklch(85% 0.21 250);

  --color-surface:              oklch(1 0 0);           /* bg-surface */
  --color-on-surface:           oklch(0.28 0.01 250);   /* text-on-surface */
  --color-surface-dark:         oklch(0.22 0.01 270);   /* dark:bg-surface-dark */
  --color-surface-dark-alt:     oklch(0.26 0.01 270);   /* dark:bg-surface-dark-alt */
  --color-on-surface-dark:      oklch(0.92 0.01 250);   /* dark:text-on-surface-dark */
  --color-outline:              oklch(0.86 0.01 270);   /* border-outline */
  --color-outline-dark:         oklch(0.45 0.01 270);   /* dark:border-outline-dark */
}
@theme inline {
  --color-login-success: var(--color-success);
  --color-login-error: var(--color-error);
}
