@layer utilities {
  /* ✅ Forcer Tailwind à ne pas supprimer ces classes */
  .text-error { @apply text-error; }
  .text-login-error { @apply text-login-error; }
  .icon-error:before {
    @apply content-["\e088"] text-2xl;
  }
  .icon-login-error:before {
    @apply content-["\e1ff"] text-2xl;
  }
  .text-success { @apply text-success; }
  .text-login-success { @apply text-login-success; }
  .icon-success:before {
    @apply content-["\e080"] text-2xl;
  }
  .icon-login-success:before {
    @apply content-["\e1fe"] text-2xl;
  }
  .text-warning { @apply text-warning; }
  .icon-warning:before {
    @apply text-2xl content-["\e192"] ;
  }
  .text-info { @apply text-info; }
  .icon-info:before {
    @apply content-["\e0fe"] text-2xl;
  }

  [x-cloak] { display: none !important; }
}
