{% extends "@SerenityAdmin/layout/base.html.twig" %}
{% block title %}

{% endblock %}
{% block h2 %}Configuration Administration{% endblock %}
{% block main %}
<twig:SerenityCore:Form:ConfigForm
  formType="Serenity\\AdminBundle\\Form\\Type\\SuperAdminConfigType"
  messageSuccess="{{ 'form.success'|trans([], 'serenity_core_messages.admin') }}" />
{% endblock %}
